@@ -221,18 +221,17 @@ function (L)
 
   jj <- as.matrix(expand.grid(rep(list(0:1),n))) 
   
-  wrapper <- function(x, y, my.fun) {
+  wrapper <- function(x, y) {
     f <- function(x,y,tol=1e-4){
       abs(sum(abs(jj[x,]-jj[y,]))-1)<tol
     }
     sapply(seq(along = x), FUN = function(i){f(x[i], y[i])})
   }
   
-  o <- -outer(1:(2^n),1:(2^n), wrapper, my.fun=f)
+  o <- -outer(1:(2^n),1:(2^n), wrapper)
   jj.names <- apply(jj,1,paste,collapse="")
   rownames(o) <- jj.names
   colnames(o) <- jj.names
   diag(o) <- -apply(o,1,sum,na.rm=TRUE)
   return(o)
 }
-
